pub struct Block {
pub start: usize,
pub end: usize,
pub btype: BlockType,
}Expand description
A basic block in the control flow graph representing a sequence of instructions with a single entry point and a single exit point
Fields
start: usizeByte offset where the block’s first opcode begins
end: usizeByte offset where the block’s last opcode begins
btype: BlockTypeType of the block indicating how control flow continues after this block